==> servicecatalog-model-6.8.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerAuthInfoFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServiceBrokerAuthInfoFluent<A extends ClusterServiceBrokerAuthInfoFluent<A>> extends BaseFluent<A>{
  public ClusterServiceBrokerAuthInfoFluent() {
  }
  public ClusterServiceBrokerAuthInfoFluent(ClusterServiceBrokerAuthInfo instance) {
    instance = (instance != null ? instance : new ClusterServiceBrokerAuthInfo());

    if (instance != null) {
      this.withBasic(instance.getBasic());
      this.withBearer(instance.getBearer());
      this.withBasic(instance.getBasic());
      this.withBearer(instance.getBearer());
    }
  }
  private ClusterBasicAuthConfigBuilder basic;
  private ClusterBearerTokenAuthConfigBuilder bearer;
  public ClusterBasicAuthConfig buildBasic() {
    return this.basic!=null ?this.basic.build():null;
  }
  public A withBasic(ClusterBasicAuthConfig basic) {
    _visitables.get("basic").remove(this.basic);
    if (basic!=null){ this.basic= new ClusterBasicAuthConfigBuilder(basic); _visitables.get("basic").add(this.basic);} else { this.basic = null; _visitables.get("basic").remove(this.basic); } return (A) this;
  }
  public boolean hasBasic() {
    return this.basic != null;
  }
  public BasicNested<A> withNewBasic() {
    return new BasicNested(null);
  }
  public BasicNested<A> withNewBasicLike(ClusterBasicAuthConfig item) {
    return new BasicNested(item);
  }
  public BasicNested<A> editBasic() {
    return withNewBasicLike(java.util.Optional.ofNullable(buildBasic()).orElse(null));
  }
  public BasicNested<A> editOrNewBasic() {
    return withNewBasicLike(java.util.Optional.ofNullable(buildBasic()).orElse(new ClusterBasicAuthConfigBuilder().build()));
  }
  public BasicNested<A> editOrNewBasicLike(ClusterBasicAuthConfig item) {
    return withNewBasicLike(java.util.Optional.ofNullable(buildBasic()).orElse(item));
  }
  public ClusterBearerTokenAuthConfig buildBearer() {
    return this.bearer!=null ?this.bearer.build():null;
  }
  public A withBearer(ClusterBearerTokenAuthConfig bearer) {
    _visitables.get("bearer").remove(this.bearer);
    if (bearer!=null){ this.bearer= new ClusterBearerTokenAuthConfigBuilder(bearer); _visitables.get("bearer").add(this.bearer);} else { this.bearer = null; _visitables.get("bearer").remove(this.bearer); } return (A) this;
  }
  public boolean hasBearer() {
    return this.bearer != null;
  }
  public BearerNested<A> withNewBearer() {
    return new BearerNested(null);
  }
  public BearerNested<A> withNewBearerLike(ClusterBearerTokenAuthConfig item) {
    return new BearerNested(item);
  }
  public BearerNested<A> editBearer() {
    return withNewBearerLike(java.util.Optional.ofNullable(buildBearer()).orElse(null));
  }
  public BearerNested<A> editOrNewBearer() {
    return withNewBearerLike(java.util.Optional.ofNullable(buildBearer()).orElse(new ClusterBearerTokenAuthConfigBuilder().build()));
  }
  public BearerNested<A> editOrNewBearerLike(ClusterBearerTokenAuthConfig item) {
    return withNewBearerLike(java.util.Optional.ofNullable(buildBearer()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerAuthInfoFluent that = (ClusterServiceBrokerAuthInfoFluent) o;
    if (!java.util.Objects.equals(basic, that.basic)) return false;

    if (!java.util.Objects.equals(bearer, that.bearer)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(basic,  bearer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (basic != null) { sb.append("basic:"); sb.append(basic + ","); }
    if (bearer != null) { sb.append("bearer:"); sb.append(bearer); }
    sb.append("}");
    return sb.toString();
  }
  public class BasicNested<N> extends ClusterBasicAuthConfigFluent<BasicNested<N>> implements Nested<N>{
    BasicNested(ClusterBasicAuthConfig item) {
      this.builder = new ClusterBasicAuthConfigBuilder(this, item);
    }
    ClusterBasicAuthConfigBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerAuthInfoFluent.this.withBasic(builder.build());
    }
    public N endBasic() {
      return and();
    }
    
  }
  public class BearerNested<N> extends ClusterBearerTokenAuthConfigFluent<BearerNested<N>> implements Nested<N>{
    BearerNested(ClusterBearerTokenAuthConfig item) {
      this.builder = new ClusterBearerTokenAuthConfigBuilder(this, item);
    }
    ClusterBearerTokenAuthConfigBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerAuthInfoFluent.this.withBearer(builder.build());
    }
    public N endBearer() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerAuthInfoFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterServiceBrokerAuthInfoFluent<A extends ClusterServiceBrokerAuthInfoFluent<A>> extends BaseFluent<A>{
  public ClusterServiceBrokerAuthInfoFluent() {
  }
  
  public ClusterServiceBrokerAuthInfoFluent(ClusterServiceBrokerAuthInfo instance) {
    this.copyInstance(instance);
  }
  private ClusterBasicAuthConfigBuilder basic;
  private ClusterBearerTokenAuthConfigBuilder bearer;
  
  protected void copyInstance(ClusterServiceBrokerAuthInfo instance) {
    instance = (instance != null ? instance : new ClusterServiceBrokerAuthInfo());
  
    if (instance != null) {
        this.withBasic(instance.getBasic());
        this.withBearer(instance.getBearer());
        this.withBasic(instance.getBasic());
        this.withBearer(instance.getBearer());
      }
  }
  
  public ClusterBasicAuthConfig buildBasic() {
    return this.basic!=null ?this.basic.build():null;
  }
  
  public A withBasic(ClusterBasicAuthConfig basic) {
    _visitables.get("basic").remove(this.basic);
    if (basic!=null){ this.basic= new ClusterBasicAuthConfigBuilder(basic); _visitables.get("basic").add(this.basic);} else { this.basic = null; _visitables.get("basic").remove(this.basic); } return (A) this;
  }
  
  public boolean hasBasic() {
    return this.basic != null;
  }
  
  public BasicNested<A> withNewBasic() {
    return new BasicNested(null);
  }
  
  public BasicNested<A> withNewBasicLike(ClusterBasicAuthConfig item) {
    return new BasicNested(item);
  }
  
  public BasicNested<A> editBasic() {
    return withNewBasicLike(java.util.Optional.ofNullable(buildBasic()).orElse(null));
  }
  
  public BasicNested<A> editOrNewBasic() {
    return withNewBasicLike(java.util.Optional.ofNullable(buildBasic()).orElse(new ClusterBasicAuthConfigBuilder().build()));
  }
  
  public BasicNested<A> editOrNewBasicLike(ClusterBasicAuthConfig item) {
    return withNewBasicLike(java.util.Optional.ofNullable(buildBasic()).orElse(item));
  }
  
  public ClusterBearerTokenAuthConfig buildBearer() {
    return this.bearer!=null ?this.bearer.build():null;
  }
  
  public A withBearer(ClusterBearerTokenAuthConfig bearer) {
    _visitables.get("bearer").remove(this.bearer);
    if (bearer!=null){ this.bearer= new ClusterBearerTokenAuthConfigBuilder(bearer); _visitables.get("bearer").add(this.bearer);} else { this.bearer = null; _visitables.get("bearer").remove(this.bearer); } return (A) this;
  }
  
  public boolean hasBearer() {
    return this.bearer != null;
  }
  
  public BearerNested<A> withNewBearer() {
    return new BearerNested(null);
  }
  
  public BearerNested<A> withNewBearerLike(ClusterBearerTokenAuthConfig item) {
    return new BearerNested(item);
  }
  
  public BearerNested<A> editBearer() {
    return withNewBearerLike(java.util.Optional.ofNullable(buildBearer()).orElse(null));
  }
  
  public BearerNested<A> editOrNewBearer() {
    return withNewBearerLike(java.util.Optional.ofNullable(buildBearer()).orElse(new ClusterBearerTokenAuthConfigBuilder().build()));
  }
  
  public BearerNested<A> editOrNewBearerLike(ClusterBearerTokenAuthConfig item) {
    return withNewBearerLike(java.util.Optional.ofNullable(buildBearer()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerAuthInfoFluent that = (ClusterServiceBrokerAuthInfoFluent) o;
    if (!java.util.Objects.equals(basic, that.basic)) return false;
  
    if (!java.util.Objects.equals(bearer, that.bearer)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(basic,  bearer,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (basic != null) { sb.append("basic:"); sb.append(basic + ","); }
    if (bearer != null) { sb.append("bearer:"); sb.append(bearer); }
    sb.append("}");
    return sb.toString();
  }
  public class BasicNested<N> extends ClusterBasicAuthConfigFluent<BasicNested<N>> implements Nested<N>{
    BasicNested(ClusterBasicAuthConfig item) {
      this.builder = new ClusterBasicAuthConfigBuilder(this, item);
    }
    ClusterBasicAuthConfigBuilder builder;
    
    public N and() {
      return (N) ClusterServiceBrokerAuthInfoFluent.this.withBasic(builder.build());
    }
    
    public N endBasic() {
      return and();
    }
    
  
  }
  public class BearerNested<N> extends ClusterBearerTokenAuthConfigFluent<BearerNested<N>> implements Nested<N>{
    BearerNested(ClusterBearerTokenAuthConfig item) {
      this.builder = new ClusterBearerTokenAuthConfigBuilder(this, item);
    }
    ClusterBearerTokenAuthConfigBuilder builder;
    
    public N and() {
      return (N) ClusterServiceBrokerAuthInfoFluent.this.withBearer(builder.build());
    }
    
    public N endBearer() {
      return and();
    }
    
  
  }

}
